# Plugin documentation

This plugin detects language from given string.

# Requirements

If you want to use this plugin, you need to create account on https://www.meaningcloud.com and get a access key.